@@ -4,7 +4,6 @@ import argparse
 
 from pytype import config as pytype_config
 from pytype import datatypes
-from pytype import utils as pytype_utils
 from pytype.tools import arg_parser
 from pytype.tools.xref import kythe
 
@@ -25,11 +24,6 @@ def make_parser():
   add_kythe_field(parser, "kythe_corpus")
   add_kythe_field(parser, "kythe_root")
   add_kythe_field(parser, "kythe_path")
-  parser.add_argument("inputs", metavar="input", nargs=1,
-                      help="A .py file to index")
-  parser.add_argument("--debug", action="store_true",
-                      dest="debug", default=None,
-                      help="Display debug output.")
   # For the debug indexer
   parser.add_argument("--show-types", action="store_true",
                       dest="show_types", default=None,
@@ -37,11 +31,6 @@ def make_parser():
   parser.add_argument("--show-kythe", action="store_true",
                       dest="show_kythe", default=None,
                       help="Display kythe facts.")
-  # TODO(b/124802213): There should be a cleaner way to do this.
-  parser.add_argument(
-      "--imports_info", type=str, action="store",
-      dest="imports_info", default=None,
-      help="Information for mapping import .pyi to files. ")
   # Don't index builtins and stdlib.
   parser.add_argument("--skip-stdlib", action="store_true",
                       dest="skip_stdlib", default=None,
@@ -49,7 +38,12 @@ def make_parser():
   # Add options from pytype-single.
   wrapper = datatypes.ParserWrapper(parser)
   pytype_config.add_basic_options(wrapper)
-  return arg_parser.Parser(parser, wrapper.actions)
+  with wrapper.add_only(["--imports_info", "--debug"]):
+    pytype_config.add_infrastructure_options(wrapper)
+    pytype_config.add_debug_options(wrapper)
+  wrapper.add_argument("input", metavar="input", nargs=1,
+                       help="A .py file to index")
+  return arg_parser.Parser(parser, pytype_single_args=wrapper.actions)
 
 
 def parse_args(argv):
@@ -67,20 +61,9 @@ def parse_args(argv):
 
   parser = make_parser()
   args = parser.parse_args(argv)
-  cli_args = args.inputs.copy()
-  # If we are passed an imports map we should look for pickled files as well.
-  if args.imports_info:
-    cli_args += ["--imports_info", args.imports_info,
-                 "--use-pickled-files"]
-
-  # We need to set this when creating Options (b/128032570)
-  if args.python_version:
-    cli_args += ["-V", pytype_utils.format_version(args.python_version)]
-
-  pytype_options = pytype_config.Options(cli_args, command_line=True)
-  pytype_options.tweak(**parser.get_pytype_kwargs(args))
+  t = args.tool_args
   kythe_args = kythe.Args(
-      corpus=args.kythe_corpus, root=args.kythe_root, path=args.kythe_path,
-      skip_stdlib=args.skip_stdlib
+      corpus=t.kythe_corpus, root=t.kythe_root, path=t.kythe_path,
+      skip_stdlib=t.skip_stdlib
   )
-  return (args, kythe_args, pytype_options)
+  return (args.all_args, kythe_args, args.pytype_opts)
