@@ -27,7 +27,7 @@ log = logging.getLogger(__name__)
 # Most interpreter functions (including lambdas) need to be analyzed as
 # stand-alone functions. The exceptions are comprehensions and generators, which
 # have names like "<listcomp>" and "<genexpr>".
-_SKIP_FUNCTION_RE = re.compile("<(?!lambda).+>$")
+_SKIP_FUNCTION_RE = re.compile(r"<(?!lambda)\w+>$")
 
 
 @dataclasses.dataclass(eq=True, frozen=True)
@@ -675,7 +675,8 @@ class CallTracer(vm.VirtualMachine):
   def _check_return(self, node, actual, formal):
     if not self.ctx.options.report_errors:
       return True
-    bad, _ = self.ctx.matcher(node).bad_matches(actual, formal)
-    if bad:
-      self.ctx.errorlog.bad_return_type(self.frames, node, bad)
-    return not bad
+    match_result = self.ctx.matcher(node).compute_matches(actual, formal)
+    if not match_result.success:
+      self.ctx.errorlog.bad_return_type(
+          self.frames, node, match_result.bad_matches)
+    return match_result.success
